@@ -48,15 +48,15 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'WTForms'
-copyright = '2010 by Thomas Johansson, James Crasta'
+copyright = '2010-2014 by Thomas Johansson, James Crasta'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '2.0.1'
+version = '2.1'
 # The full version, including alpha/beta/rc tags.
-release = '2.0.1'
+release = '2.1'
 
 
 # There are two options for replacing |today|: either, you set today to some
